@@ -9,11 +9,10 @@ ldap.set_option(ldap.OPT_TIMEOUT, 10.0)
 # connect to ldap
 def connect_to_ldap(config):
     # configure TLS
-    starttls = False
-    if config.server.startswith('ldaps:') or config.starttls:
+    if config.server.startswith('ldaps:'):
         log.info("Using SSL/TLS")
         ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_DEMAND)
-        starttls = True
+
     
     if config.ignore_cert:
         log.info("Ignoring SSL/TLS certificate")
@@ -22,7 +21,7 @@ def connect_to_ldap(config):
     log.info('Connecting to ' + config.server)
     con = ldap.initialize(config.server)
     
-    if starttls:
+    if config.starttls:
         log.info('Starting TLS')
         con.start_tls_s()
     
